@@ -33,7 +33,7 @@ X, y = datasets.load_digits(return_X_y=True)
 X = StandardScaler().fit_transform(X)
 
 # classify small against large digits
-y = (y > 4).astype(np.int)
+y = (y > 4).astype(int)
 
 l1_ratio = 0.5  # L1 weight in the Elastic-Net regularization
 
